```
Usage: vcd vm copy [OPTIONS] <vapp-name> <vm-name>

Options:
  --target-vapp-name <target-vapp>
                                  target vapp name  [required]
  --target-vm-name <target-vm>    target vm name  [required]
  -h, --help                      Show this message and exit.

```
